@@ -1,12 +1,14 @@
 import logging
 import pickle
-from typing import Optional
+from typing import Any, Optional, Tuple
 from lenses import lens
 from pathlib import Path
 from uuid import uuid4
 
 from instancelib.utils.func import list_unzip
 
+from allib.activelearning.base import ActiveLearner
+
 from .analysis.tarplotter import TarExperimentPlotter
 from .benchmarking.datasets import TarDataset, DatasetType
 from .benchmarking.reviews import benchmark, read_review_dataset
@@ -31,7 +33,9 @@ def tar_benchmark(
     neg_label: str,
     stop_interval: Optional[int] = None,
     enable_plots=True,
-) -> None:
+    seed: Optional[int] = None,
+    max_it: Optional[int] = None
+) -> Tuple[ActiveLearner[Any, Any, Any, Any, Any, str],TarExperimentPlotter[str]]:
     LOGGER.info(
         f"Start Experiment on {dataset.path.stem} for topic ´{dataset.topic}´ with {exp_choice}"
     )
@@ -58,7 +62,7 @@ def tar_benchmark(
     stop_criteria = flatten_dicts(*stop_criteria_dicts)
 
     # Specify benchmark targets and outputs
-    uuid = uuid4()
+    run_id = uuid4()
     target_path = Path(target_path)
     dataset_name = (
         dataset.path.stem
@@ -67,12 +71,13 @@ def tar_benchmark(
     )
     # File locations for the plotter object
     dataset_dir = target_path / dataset_name
-    plot_filename_pkl = dataset_dir / f"run_{uuid}.pkl"
-    plot_filename_pdf = dataset_dir / f"run_{uuid}.pdf"
-
+    method_dir = dataset_dir / str(exp_choice)
+    create_dir_if_not_exists(method_dir)
+    plot_filename_pkl = method_dir / f"run_{run_id}_{seed}.pkl"
+    plot_filename_pdf = method_dir / f"run_{run_id}_{seed}.pdf"
     # Load the dataset
     create_dir_if_not_exists(dataset_dir)
-    plot = benchmark(
+    al, plot = benchmark(
         dataset.env,
         plot_filename_pkl,
         plot_filename_pdf,
@@ -87,7 +92,11 @@ def tar_benchmark(
         stop_interval=exp.stop_interval,
         estimation_interval=exp.estimation_interval,
         enable_plots=enable_plots,
+        seed=seed,
+        max_it=max_it
     )
     with plot_filename_pkl.open("wb") as fh:
         pickle.dump(plot, fh)
-    plot.show(filename=plot_filename_pdf)
+    if plot.it > 1:
+        plot.show(filename=plot_filename_pdf)
+    return al, plot
