@@ -19,8 +19,15 @@ class ALConfiguration(Enum):
     AUTOSTOP = "AUTOSTOP"
     CHAO_AT_ENSEMBLE = "CHAO_AT_ENSEMBLE"
     CHAO_IB_ENSEMBLE = "CHAO_IB_ENSEMBLE"
+    CHAO_IB_ENSEMBLE_20 = "CHAO_IB_ENSEMBLE_20"
+    CHAO_SAME = "CHAO_SAME"
     TARGET = "TARGET"
     PRIOR = "PRIOR"
+    AUTOSTOP_LARGE_CONS_95 = "AUTOSTOP_LARGE_CONS_95"
+    AUTOSTOP_LARGE_CONS_100 = "AUTOSTOP_LARGE_CONS_100"
+    AUTOSTOP_LARGE_OPT_95 = "AUTOSTOP_LARGE_OPT_95"
+    AUTOSTOP_LARGE_OPT_100 = "AUTOSTOP_LARGE_OPT_100"
+    CMH = "CMH"
 
 
 class INITConfiguration(Enum):
@@ -54,16 +61,27 @@ class StopBuilderConfiguration(str, Enum):
     AUTOTAR = "AUTOTAR"
     AUTOSTOP = "AUTOSTOP"
     TARGET = "Target"
+    LASTSEQUENCE = "LastSequence"
+    QUANT = "QUANT"
+    CMH = "CMH"
 
 
 class ExperimentCombination(str, Enum):
+    CMH = "CMH"
     CHAO = "CHAO"
     CHAO_ALT = "CHAO_ALT"
     CHAO_BOTH = "CHAO_BOTH"
     AUTOTAR = "AUTOTAR"
+    AUTOTAR_QUANT = "AUTOTAR_QUANT"
     AUTOSTOP = "AUTOSTOP"
     CHAO_AT = "CHAO_AT"
     CHAO_IB = "CHAO_IB"
+    CHAO_IB_20 = "CHAO_IB_20"
+    CHAO_SAME = "CHAO_SAME"
     RCAPTURE = "RCAPTURE"
     TARGET = "TARGET"
     PRIOR = "PRIOR"
+    AUTOSTOP_LARGE_CONS_95 = "AUTOSTOP_LARGE"
+    AUTOSTOP_LARGE_CONS_100 = "AUTOSTOP_LARGE_CONS_100"
+    AUTOSTOP_LARGE_OPT_95 = "AUTOSTOP_LARGE_OPT_95"
+    AUTOSTOP_LARGE_OPT_100 = "AUTOSTOP_LARGE_OPT_100"
