@@ -35,18 +35,16 @@ class BinaryTARBuilder(AbstractBuilder):
         feature_extraction: Mapping[str, Any],
         model_configuration: Mapping[str, Any],
         balancer: Mapping[str, Any],
-        vectorstorage=SparseVectorStorage(),
+        vectorstorage=SparseVectorStorage,
         storage_location=None,
         filename=None,
         **kwargs
     ):
-        vectorizer = self._factory.create(
-            Component.FEATURE_EXTRACTION, **feature_extraction
-        )
-        built_balancer = self._factory.create(Component.BALANCER, **balancer)
-        classifier = self._factory.create(sklearn_model, **model_configuration)
-
         def builder(env):
+            vectorizer = self._factory.create(
+            Component.FEATURE_EXTRACTION, **feature_extraction)
+            built_balancer = self._factory.create(Component.BALANCER, **balancer)
+            classifier = self._factory.create(sklearn_model, **model_configuration)
             return ALSklearn.build(
                 classifier,
                 env,
